@@ -7,6 +7,11 @@ from MSApi.ProductFolder import ProductFolder
 from MSApi.PriceType import PriceType
 from MSApi.Meta import Meta
 
+from MSApi.mixin.GenListMixin import GenerateListMixin
+from MSApi.mixin.CreateNewMixin import CreateNewMixin
+from MSApi.mixin.NameMixin import NameMixin
+from MSApi.mixin.AccountIdMixin import AccountIdMixin
+
 
 class SpecialPrice(SubObjectMS):
     def __init__(self, json):
@@ -38,18 +43,12 @@ class DiscountLevel(SubObjectMS):
         return float(discount) / 100
 
 
-class Discount(ObjectMS):
-    def __init__(self, json):
-        super().__init__(json)
-
-    def get_id(self) -> str:
-        return self._json.get('id')
-
-    def get_account_id(self) -> str:
-        return self._json.get('accountId')
-
-    def get_name(self) -> str:
-        return self._json.get('name')
+class Discount(ObjectMS,
+               GenerateListMixin,
+               CreateNewMixin,
+               NameMixin,
+               AccountIdMixin):
+    _type_name = 'discount'
 
     def is_active(self) -> bool:
         return bool(self._json.get('active'))
@@ -76,8 +75,7 @@ class Discount(ObjectMS):
 
 
 class SpecialPriceDiscount(Discount):
-    def __init__(self, json):
-        super().__init__(json)
+    _type_name = 'specialpricediscount'
 
     def gen_productfolders(self):
         """Группы товаров, к которым применяется скидка, если применяется не ко всем товарам"""
@@ -106,8 +104,7 @@ class SpecialPriceDiscount(Discount):
 
 
 class AccumulationDiscount(Discount):
-    def __init__(self, json):
-        super().__init__(json)
+    _type_name = 'accumulationdiscount'
 
     def gen_productfolders(self):
         """Группы товаров, к которым применяется скидка, если применяется не ко всем товарам"""
