@@ -11,7 +11,6 @@ from MSApi.Template import Template
 from MSApi.Product import Product
 from MSApi.Service import Service
 from MSApi.ProductFolder import ProductFolder
-from MSApi.Discount import Discount, SpecialPriceDiscount, AccumulationDiscount
 from MSApi.PriceType import PriceType
 from MSApi.CompanySettings import CompanySettings
 from MSApi.Bundle import Bundle
@@ -104,26 +103,6 @@ class MSApi(MSLowApi):
     def gen_productfolders(cls, **kwargs):
         return cls.gen_objects('entity/productfolder', ProductFolder, **kwargs)
 
-    @classmethod
-    @caching
-    def gen_discounts(cls, **kwargs):
-        return cls.gen_objects('entity/discount', Discount, **kwargs)
-
-    @classmethod
-    @caching
-    def gen_special_price_discounts(cls, **kwargs):
-        return cls.gen_objects('entity/specialpricediscount', SpecialPriceDiscount, **kwargs)
-
-    @classmethod
-    @caching
-    def gen_accumulation_discounts(cls, **kwargs):
-        return cls.gen_objects('entity/accumulationdiscount', AccumulationDiscount, **kwargs)
-
-    @classmethod
-    @caching
-    def gen_customer_orders(cls, **kwargs):
-        return cls.gen_objects('entity/customerorder', CustomerOrder, **kwargs)
-
     @classmethod
     def get_product_by_id(cls, product_id, **kwargs):
         response = cls.auch_get(f'entity/product/{product_id}', **kwargs)
