@@ -1,7 +1,7 @@
 from typing import Optional
 from datetime import datetime
 
-from MSApi.documents import DocumentMS, check_init
+from MSApi.documents.DocumentMS import DocumentMS, check_init
 from MSApi.MSLowApi import MSLowApi, error_handler, caching
 from MSApi.State import State
 
