@@ -21,5 +21,5 @@ class Order:
 
     @staticmethod
     def _append_order(order_, parameter, operator):
-        order_.orders.append(f"{parameter}{operator}")
+        order_.orders.append(f"{parameter},{operator}")
         return order_
